/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/*
* When adding modules to the namespace, ensure that they are added in alphabetical order according to module name.
*/

// MODULES //

var setReadOnly = require( '@stdlib/utils/define-read-only-property' );


// MAIN //

/**
* Top-level namespace.
*
* @namespace nlp
*/
var nlp = {};

/**
* @name expandAcronyms
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/expand-acronyms}
*/
setReadOnly( nlp, 'expandAcronyms', require( './../expand-acronyms' ) );

/**
* @name expandContractions
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/expand-contractions}
*/
setReadOnly( nlp, 'expandContractions', require( './../expand-contractions' ) );

/**
* @name lda
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/lda}
*/
setReadOnly( nlp, 'lda', require( './../lda' ) );

/**
* @name ordinalize
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/ordinalize}
*/
setReadOnly( nlp, 'ordinalize', require( './../ordinalize' ) );

/**
* @name porterStemmer
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/porter-stemmer}
*/
setReadOnly( nlp, 'porterStemmer', require( './../porter-stemmer' ) );

/**
* @name sentencize
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/sentencize}
*/
setReadOnly( nlp, 'sentencize', require( './../sentencize' ) );

/**
* @name tokenize
* @memberof nlp
* @readonly
* @type {Function}
* @see {@link module:@stdlib/nlp/tokenize}
*/
setReadOnly( nlp, 'tokenize', require( './../tokenize' ) );


// EXPORTS //

module.exports = nlp;
